__name__ = 'vocmax'
__version__ = '0.0.21'

from vocmax.main import *
import vocmax.nsrdb